=======
History
=======

0.1.0 (2020-07-27)
------------------

* First release on PyPI.

0.1.1 (2020-08-01)
------------------

* Multiple independent, dependent, and control variables implemented as lists. Mutually exclusive control variables implemented. Expansions of categorical variables into mutually exclusive fixed effects implemented.
